@@ -9,7 +9,7 @@ try:
 except ImportError:
     pass
 
-__version__ = '5.8.1'
+__version__ = '5.8.2'
 
 # Context Flags
 
@@ -102,18 +102,6 @@ class Buffer:
         self.extra = None
         raise TypeError()
 
-    def __repr__(self) -> str:
-        if hasattr(self, '_glo'):
-            return f"<{self.__class__.__name__}: {self._glo}>"
-        else:
-            return f"<{self.__class__.__name__}: INCOMPLETE>"
-
-    def __eq__(self, other: Any):
-        return type(self) is type(other) and self.mglo is other.mglo
-
-    def __hash__(self) -> int:
-        return id(self)
-
     def __del__(self) -> None:
         if not hasattr(self, "ctx"):
             return
@@ -191,9 +179,6 @@ class ConditionalRender:
         self.mglo = None
         raise TypeError()
 
-    def __repr__(self):
-        return '<ConditionalRender>'
-
     def __enter__(self):
         self.mglo.begin_render()
         return self
@@ -210,12 +195,6 @@ class Query:
         self.extra = None
         raise TypeError()
 
-    def __repr__(self) -> str:
-        return '<Query>'
-
-    def __hash__(self) -> int:
-        return id(self)
-
     def __enter__(self):
         self.mglo.begin()
         return self
@@ -245,18 +224,6 @@ class ComputeShader:
         self.extra = None
         raise TypeError()
 
-    def __repr__(self) -> str:
-        if hasattr(self, '_glo'):
-            return f"<{self.__class__.__name__}: {self._glo}>"
-        else:
-            return f"<{self.__class__.__name__}: INCOMPLETE>"
-
-    def __eq__(self, other: Any):
-        return type(self) is type(other) and self.mglo is other.mglo
-
-    def __hash__(self) -> int:
-        return id(self)
-
     def __del__(self) -> None:
         if not hasattr(self, "ctx"):
             return
@@ -283,7 +250,7 @@ class ComputeShader:
         return self.mglo.run(group_x, group_y, group_z)
 
     def run_indirect(self, buffer: 'Buffer', offset: int = 0) -> None:
-        return self.mglo.run(buffer, offset)
+        return self.mglo.run_indirect(buffer.mglo, offset)
 
     def get(self, key: str, default: Any) -> Union[Uniform, UniformBlock, Subroutine, Attribute, Varying]:
         return self._members.get(key, default)
@@ -307,18 +274,6 @@ class Framebuffer:
         self.extra: Any = None
         raise TypeError()
 
-    def __repr__(self) -> str:
-        if hasattr(self, '_glo'):
-            return '<Framebuffer: %d>' % self._glo
-        else:
-            return "<Framebuffer: INCOMPLETE>"
-
-    def __eq__(self, other: Any) -> bool:
-        return type(self) is type(other) and self.mglo is other.mglo
-
-    def __hash__(self) -> int:
-        return id(self)
-
     def __del__(self):
         if not hasattr(self, "ctx"):
             return
@@ -473,18 +428,6 @@ class Program:
         self.extra = None
         raise TypeError()
 
-    def __repr__(self):
-        if hasattr(self, '_glo'):
-            return f"<{self.__class__.__name__}: {self._glo}>"
-        else:
-            return f"<{self.__class__.__name__}: INCOMPLETE>"
-
-    def __eq__(self, other: Any) -> bool:
-        return type(self) is type(other) and self.mglo is other.mglo
-
-    def __hash__(self) -> int:
-        return id(self)
-
     def __del__(self):
         if not hasattr(self, "ctx"):
             return
@@ -549,18 +492,6 @@ class Renderbuffer:
         self.extra = None
         raise TypeError()
 
-    def __repr__(self):
-        if hasattr(self, '_glo'):
-            return f"<{self.__class__.__name__}: {self._glo}>"
-        else:
-            return f"<{self.__class__.__name__}: INCOMPLETE>"
-
-    def __eq__(self, other: Any):
-        return type(self) is type(other) and self.mglo is other.mglo
-
-    def __hash__(self) -> int:
-        return id(self)
-
     def __del__(self) -> None:
         if not hasattr(self, "ctx"):
             return
@@ -617,15 +548,6 @@ class Sampler:
         self.texture = None
         raise TypeError()
 
-    def __hash__(self) -> int:
-        return id(self)
-
-    def __repr__(self):
-        if hasattr(self, '_glo'):
-            return f"<{self.__class__.__name__}: {self._glo}>"
-        else:
-            return f"<{self.__class__.__name__}: INCOMPLETE>"
-
     def __del__(self):
         if not hasattr(self, "ctx"):
             return
@@ -737,12 +659,6 @@ class Scope:
         self.extra = None
         raise TypeError()
 
-    def __repr__(self):
-        return '<Scope>'
-
-    def __hash__(self) -> int:
-        return id(self)
-
     def __enter__(self):
         self.mglo.begin()
         return self
@@ -783,18 +699,6 @@ class Texture:
         self.extra = None
         raise TypeError()
 
-    def __repr__(self):
-        if hasattr(self, '_glo'):
-            return f"<{self.__class__.__name__}: {self._glo}>"
-        else:
-            return f"<{self.__class__.__name__}: INCOMPLETE>"
-
-    def __eq__(self, other: Any):
-        return type(self) is type(other) and self.mglo is other.mglo
-
-    def __hash__(self) -> int:
-        return id(self)
-
     def __del__(self):
         if not hasattr(self, "ctx"):
             return
@@ -943,18 +847,6 @@ class Texture3D:
         self.extra = None
         raise TypeError()
 
-    def __repr__(self):
-        if hasattr(self, '_glo'):
-            return f"<{self.__class__.__name__}: {self._glo}>"
-        else:
-            return f"<{self.__class__.__name__}: INCOMPLETE>"
-
-    def __eq__(self, other: Any):
-        return type(self) is type(other) and self.mglo is other.mglo
-
-    def __hash__(self) -> int:
-        return id(self)
-
     def __del__(self):
         if not hasattr(self, "ctx"):
             return
@@ -1088,18 +980,6 @@ class TextureCube:
         self.extra = None
         raise TypeError()
 
-    def __repr__(self):
-        if hasattr(self, '_glo'):
-            return f"<{self.__class__.__name__}: {self._glo}>"
-        else:
-            return f"<{self.__class__.__name__}: INCOMPLETE>"
-
-    def __eq__(self, other: Any):
-        return type(self) is type(other) and self.mglo is other.mglo
-
-    def __hash__(self) -> int:
-        return id(self)
-
     def __del__(self) -> None:
         if not hasattr(self, "ctx"):
             return
@@ -1209,18 +1089,6 @@ class TextureArray:
         self.extra = None
         raise TypeError()
 
-    def __repr__(self):
-        if hasattr(self, '_glo'):
-            return f"<{self.__class__.__name__}: {self._glo}>"
-        else:
-            return f"<{self.__class__.__name__}: INCOMPLETE>"
-
-    def __eq__(self, other: Any):
-        return type(self) is type(other) and self.mglo is other.mglo
-
-    def __hash__(self) -> int:
-        return id(self)
-
     def __del__(self):
         if not hasattr(self, "ctx"):
             return
@@ -1357,18 +1225,6 @@ class VertexArray:
         self.scope = None
         raise TypeError()
 
-    def __repr__(self) -> str:
-        if hasattr(self, 'mglo'):
-            return '<VertexArray: %d>' % self.glo
-        else:
-            return '<VertexArray: INCOMPLETE>'
-
-    def __eq__(self, other: Any) -> bool:
-        return type(self) is type(other) and self.mglo is other.mglo
-
-    def __hash__(self) -> int:
-        return id(self)
-
     def __del__(self) -> None:
         if not hasattr(self, "ctx"):
             return
@@ -1602,15 +1458,6 @@ class Context:
         self._objects: Deque[Any] = deque()
         raise TypeError()
 
-    def __repr__(self) -> str:
-        return f"<Context {id(self)} version_code={self.version_code}>"
-
-    def __eq__(self, other: Any):
-        return type(self) is type(other) and self.mglo is other.mglo
-
-    def __hash__(self) -> int:
-        return id(self)
-
     def __del__(self):
         if hasattr(self, "_gc_mode") and self._gc_mode == "auto":
             self.release()
